@@ -6,7 +6,7 @@ FILEPATH = ""
 PROGRAM = "density"
 # Whether a "density" program or "lifetime" program should be run
 
-SCALE = None
+SCALE = 147
 # Linear scale of the image (width of a single pixel in nanometers per pixel). Default value is None. If None is entered, the final density output will be in dots per pixel^2. If a numerical value is entered, the final density output will be in dots per micron^2.
 
 ############################################
@@ -14,7 +14,7 @@ SCALE = None
 ############################################
 
 LOWER_DOT_THRESH_SCALE = 1.5
-# Scaling for the lower threshold defining the brightness of the dots. The default is 1.5, which corresponds to 1.5 standard deviations above the mean. Lower this value to increase the number of faint dots detected, or raise it to reduce the number.
+# Scaling for the lower threshold defining the brightness of the dots. The default is 1.5,which corresponds to 1.5 standard deviations above the mean. Lower this value to increase the number of faint dots detected, or raise it to reduce the number.
 
 UPPER_DOT_THRESH_SCALE = 5.0
 # Scaling for the upper threshold defining the brightness of the dots. The default is 5, which corresponds to 5 standard deviations above the mean. Lower this value to reduce the number of bright dots detected, or raise it to increase the number.
@@ -124,8 +124,8 @@ LIFETIME_OUTPUT_FILENAME = "lifetimes.txt"
 FIGURE_DIRECTORY_NAME = "figures/"
 # The directory name where figures are to be saved (only if SAVE_FIGURES = True). The default is "figures/", but this can be changed if the user typically keeps a similarly named folder in their file structure for something else.
 
-FIGURE_FILETYPES = ["pdf", "png"]
+FIGURE_FILETYPES = ["pdf"]
 # The filetypes for the output figures. Multiple types can also be selected, e.g., ["png", "pdf", "tif"]. Only use the supported filetypes ("eps", "tif", "ps", "tiff", "rgba", "svg", "png", "jpg", "raw", "pdf", "svgz", "pgf", and "jpeg").
 
 FIGURE_RESOLUTION = 300
-# Resolution (DPI) of the output figures. This is for images only; PDF outputs are unaffected by this value.
+# Resolution (DPI) of the output figures. This is for images only; PDF outputs are unaffected by this value.
\ No newline at end of file
