@@ -1,5 +1,4 @@
-import settings.config as cfg
-from src.ui.DialogWindow import DialogWindow
+from dotscanner.ui.DialogWindow import DialogWindow
 import matplotlib.colors as colors
 import traceback
 
@@ -12,6 +11,8 @@ def runChecks():
 		quit()
 
 def scanConfigFileForErrors():
+	import settings.config as cfg
+	
 	matplotlibColors = set(colors.BASE_COLORS.keys())
 	for color in colors.TABLEAU_COLORS.keys():
 		matplotlibColors.add(color)
@@ -269,7 +270,7 @@ LIFETIME_OUTPUT_FILENAME = "lifetimes.txt"\n\
 FIGURE_DIRECTORY_NAME = "figures/"\n\
 # The directory name where figures are to be saved (only if SAVE_FIGURES = True). The default is "figures/", but this can be changed if the user typically keeps a similarly named folder in their file structure for something else.\n\
 \n\
-FIGURE_FILETYPES = ["pdf", "png"]\n\
+FIGURE_FILETYPES = ["pdf"]\n\
 # The filetypes for the output figures. Multiple types can also be selected, e.g., ["png", "pdf", "tif"]. Only use the supported filetypes ("eps", "tif", "ps", "tiff", "rgba", "svg", "png", "jpg", "raw", "pdf", "svgz", "pgf", and "jpeg").\n\
 \n\
 FIGURE_RESOLUTION = 300\n\
